@@ -32,7 +32,6 @@
 #include "delaywindow.h"
 
 
-
 using namespace bt;
 
 namespace utp
@@ -80,7 +79,8 @@ namespace utp
 		stats.packets_lost = 0;
 		
 		connect(this,SIGNAL(doDelayedStartTimer()),this,SLOT(delayedStartTimer()),Qt::QueuedConnection);
-		startTimer();
+		if (type == INCOMING)
+			startTimer();
 	}
 
 	Connection::~Connection()
@@ -93,7 +93,10 @@ namespace utp
 	void Connection::startConnecting()
 	{
 		if (stats.type == OUTGOING)
+		{
 			sendSYN();
+			startTimer();
+		}
 	}
 
 #if 0
@@ -214,7 +217,7 @@ namespace utp
 			case CS_FINISHED:
 				if (hdr->type == ST_DATA)
 				{
-					if (hdr->seq_nr <= stats.eof_seq_nr)
+					if (SeqNrCmpSE(hdr->seq_nr,stats.eof_seq_nr))
 					{
 						// push data into local window
 						int s = packet.size() - data_off;
